"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UnifiedShadowToggle = exports.ShadowToggle = exports.LinearShadowToggle = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeSkia = require("@shopify/react-native-skia");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _constants = require("../constants.js");
var _utils = require("../utils.js");
var _ShadowLinearGradientFill = _interopRequireDefault(require("./ShadowLinearGradientFill.js"));
var _useAnimatedOffset = require("../hooks/useAnimatedOffset.js");
var _CornerRadii = require("./CornerRadii.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const PressButton = _reactNativeReanimated.default.createAnimatedComponent(_reactNative.Pressable);
const UnifiedShadowToggle = exports.UnifiedShadowToggle = /*#__PURE__*/(0, _react.memo)(function ShadowToggle({
  width,
  height,
  isActive = false,
  activeColor,
  shadowBlur = _constants.SHADOW_BLUR,
  shadowColor = _constants.SHADOW_COLOR,
  reflectedLightColor = _constants.REFLECTED_LIGHT_COLOR,
  duration = _constants.DAMPING_DURATION,
  damping = _constants.DAMPING_RATIO,
  isReflectedLightEnabled = true,
  shadowOffset,
  reflectedLightOffset: rfOffset,
  reflectedLightBlur,
  style,
  backgroundColor,
  children,
  ...props
}) {
  // Determine the final background color (pulling from `props.style` or a default).
  const _backgroundColor = (0, _utils.getBackgroundColor)({
    backgroundColor,
    style
  });
  const shadowProps = (0, _utils.getShadowProperty)({
    shadowOffset,
    shadowColor,
    shadowBlur,
    reflectedLightOffset: rfOffset,
    reflectedLightColor,
    reflectedLightBlur
  });
  const isLinear = (0, _utils.isLinearProps)(props);
  const styleWidth = width ?? (0, _utils.numerify)(style?.width, 0);
  const styleHeight = height ?? (0, _utils.numerify)(style?.height, 0);
  const [layoutSize, setLayoutSize] = _react.default.useState({
    width: styleWidth,
    height: styleHeight
  });
  // Decide if we even need to attach onLayout; turns on when width or height is: undefined, NaN, or 0
  const needMeasure = !styleWidth || !styleHeight;

  // onLayout only does something if we truly need measure
  const onLayout = _react.default.useCallback(e => {
    if (!needMeasure) return;
    const {
      width: w,
      height: h
    } = e.nativeEvent.layout;
    setLayoutSize({
      width: w,
      height: h
    });
  }, [needMeasure]);
  const {
    depth,
    offset,
    reflectedLightOffset,
    inset,
    blurRadius,
    PressedAnimatedStyle
  } = (0, _useAnimatedOffset.useAnimatedOffset)({
    offset: shadowProps.shadowOffset,
    reflectedLightOffset: shadowProps.reflectedLightOffset,
    blurRadius: shadowProps.shadowBlur,
    damping,
    duration,
    onPressIn: props.onPressIn,
    onPressOut: props.onPressOut
  });

  // Only show the canvas if we have a valid size
  const canRenderCanvas = layoutSize.width > 0 && layoutSize.height > 0;
  const animatedBackgroundColor = (0, _reactNativeReanimated.useDerivedValue)(() => (0, _reactNativeReanimated.interpolateColor)(depth.value, [_constants.INITIAL_DEPTH, -_constants.INITIAL_DEPTH], [_backgroundColor, activeColor || _backgroundColor]));
  (0, _reactNativeReanimated.useAnimatedReaction)(() => isActive, next => {
    depth.value = (0, _reactNativeReanimated.withTiming)(next ? -_constants.INITIAL_DEPTH * damping : _constants.INITIAL_DEPTH, {
      duration
    });
  }, [isActive]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
    onLayout: onLayout,
    style: [_constants.COMMON_STYLES.canvasWrapper],
    children: [canRenderCanvas && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
      style: [_constants.COMMON_STYLES.canvas, {
        width: layoutSize.width * 1.4,
        height: layoutSize.height * 1.4
      }],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_CornerRadii.CornerRadii, {
        width: layoutSize.width,
        height: layoutSize.height,
        style: style,
        backgroundColor: animatedBackgroundColor,
        children: [isLinear && /*#__PURE__*/(0, _jsxRuntime.jsx)(_ShadowLinearGradientFill.default, {
          ...props,
          // from, to, colors, etc.
          width: layoutSize.width,
          height: layoutSize.height
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: offset.dx,
          dy: offset.dy,
          blur: blurRadius,
          color: shadowColor,
          inner: inset
        }), isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: reflectedLightOffset.dx,
          dy: reflectedLightOffset.dy,
          blur: blurRadius,
          color: reflectedLightColor,
          inner: true
        })]
      })
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(PressButton, {
      ...props,
      style: [style, _constants.COMMON_STYLES.canvasWrapper],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeReanimated.default.View, {
        style: PressedAnimatedStyle,
        children: children
      })
    })]
  });
});

/**
 * ShadowToggle
 * ----------------
 * A toggle component that casts a shadow when active.
 * The shadow effect is created using the `@shopify/react-native-skia` library.
 *
 * @param isActive - Whether the shadow is active
 * @param activeColor - The color of the shadow when active
 */
const ShadowToggle = exports.ShadowToggle = /*#__PURE__*/(0, _react.memo)(function ShadowToggle({
  ...props
}) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(UnifiedShadowToggle, {
    ...props
  });
});

/**
 * LinearShadowToggle
 * ----------------
 * A toggle component that casts a linear gradient shadow when active.
 * The shadow effect is created using the `@shopify/react-native-skia` library.
 *
 * @param isActive - Whether the shadow is active
 * @param activeColor - The color of the shadow when active
 * @param colors - The colors of the linear gradient
 * @param from - The direction of the linear gradient
 * @param to - The direction of the linear gradient
 */
const LinearShadowToggle = exports.LinearShadowToggle = /*#__PURE__*/(0, _react.memo)(function LinearShadowToggle({
  ...props
}) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(UnifiedShadowToggle, {
    ...props
  });
});
//# sourceMappingURL=ShadowToggle.js.map