"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LinearShadowView = LinearShadowView;
exports.ShadowView = ShadowView;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _utils = require("../utils.js");
var _constants = require("../constants.js");
var _reactNativeSkia = require("@shopify/react-native-skia");
var _ShadowLinearGradientFill = _interopRequireDefault(require("./ShadowLinearGradientFill.js"));
var _CornerRadii = require("./CornerRadii.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * A unified interface for both "solid" (InnerShadow) and "linear" (LinearShadow).
 * We automatically detect "linear mode" by checking if the user provides
 * gradient props (colors, from, to, etc.).
 */const UnifiedShadowView = /*#__PURE__*/(0, _react.memo)(function UnifiedShadowView({
  inset,
  isReflectedLightEnabled,
  width,
  height,
  style,
  backgroundColor,
  shadowOffset,
  shadowColor,
  shadowBlur,
  reflectedLightOffset,
  reflectedLightColor,
  reflectedLightBlur,
  children,
  ...props
}) {
  // Extract base fields
  const _backgroundColor = (0, _utils.getBackgroundColor)({
    backgroundColor,
    style
  });
  const shadowProps = (0, _utils.getShadowProperty)({
    shadowOffset,
    shadowColor,
    shadowBlur,
    reflectedLightOffset,
    reflectedLightColor,
    reflectedLightBlur
  });
  const isLinear = (0, _utils.isLinearProps)(props);

  // If isReflectedLightEnabled is undefined, default to `props.inset` (typical).
  const _isReflectedLightEnabled = isReflectedLightEnabled ?? inset;

  // Extract style-based width/height if present
  const styleWidth = width ?? (0, _utils.numerify)(style?.width, 0);
  const styleHeight = height ?? (0, _utils.numerify)(style?.height, 0);

  // Local state if we need to measure
  const [layoutSize, setLayoutSize] = _react.default.useState({
    width: styleWidth,
    height: styleHeight
  });

  // Decide if we even need to attach onLayout; turns on when width or height is: undefined, NaN, or 0
  const needMeasure = !styleWidth || !styleHeight;

  // onLayout only does something if we truly need measure
  const onLayout = _react.default.useCallback(e => {
    if (!needMeasure) return;
    const {
      width: w,
      height: h
    } = e.nativeEvent.layout;
    setLayoutSize({
      width: w,
      height: h
    });
  }, [needMeasure]);

  // Create offset style for outer shadow if needed
  const outerShadowOffset = _react.default.useMemo(() => (0, _utils.getOuterShadowOffset)({
    ...shadowProps,
    inset
  }), [shadowProps, inset]);

  // Only show the canvas if we have a valid size
  const canRenderCanvas = layoutSize.width > 0 && layoutSize.height > 0;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
    ...props,
    style: [style, _constants.COMMON_STYLES.canvasWrapper, outerShadowOffset // Possibly sets outer drop-shadow if needed
    ],
    onLayout: onLayout,
    children: [canRenderCanvas && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
      style: [_constants.COMMON_STYLES.canvas, {
        width: layoutSize.width,
        height: layoutSize.height
      }],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_CornerRadii.CornerRadii, {
        width: layoutSize.width,
        height: layoutSize.height,
        style: style,
        backgroundColor: _backgroundColor,
        children: [isLinear && /*#__PURE__*/(0, _jsxRuntime.jsx)(_ShadowLinearGradientFill.default, {
          ...props,
          // from, to, colors, etc.
          width: layoutSize.width,
          height: layoutSize.height
        }), inset && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: shadowProps.shadowOffset.width,
          dy: shadowProps.shadowOffset.height,
          blur: shadowProps.shadowBlur,
          color: shadowProps.shadowColor,
          inner: true
        }), _isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: shadowProps.reflectedLightOffset.width,
          dy: shadowProps.reflectedLightOffset.height,
          blur: shadowProps.reflectedLightBlur,
          color: shadowProps.reflectedLightColor,
          inner: true
        })]
      })
    }), children]
  });
});

/**
 * ShadowView: for a basic “solid” background shadow(no gradient props).
 *
 * @remarks
 * See {@link InnerShadowProps} for a linear gradient background shadow.
 *
 * @example
 * ```ts
 * <ShadowView style={styles.shadowView} inset>
 *   <Text>ShadowView</Text>
 * </ShadowView>
 * ```
 */
function ShadowView(props) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(UnifiedShadowView, {
    ...props
  });
}

/**
 * LinearShadowView: for a linear gradient background shadow
 * (requires e.g. colors, from, to).
 *
 * @remarks
 * See {@link LinearInnerShadowProps} for a solid background shadow.
 *
 * @example
 * ```ts
 *  <LinearShadowView
 *    style={styles.shadowView}
 *    colors={['#f1c40f', '#e74c3c']}
 *    from="top"
 *  >
 *    <Text>LinearShadowView</Text>
 *  </LinearShadowView>
 * ```
 */
function LinearShadowView(props) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(UnifiedShadowView, {
    ...props
  });
}
//# sourceMappingURL=ShadowView.js.map